"""
Setup script for ProjPack
"""

from setuptools import setup, find_packages
from pathlib import Path

# Read the README file
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text(encoding='utf-8') if (this_directory / "README.md").exists() else ""

# Simple version and metadata
__version__ = "1.0.0"

setup(
    name="projpack",
    version=__version__,
    author="Muhammad Fael",
    author_email="muhmmdfa624@gmail.com",
    description="Bundle project files into a single text file for AI analysis",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/MFael1/ProjPack",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Operating System :: OS Independent",
        "Environment :: Console",
        "Topic :: Utilities",
        "Topic :: Text Processing",
    ],
    python_requires=">=3.7",
    install_requires=[
        "chardet>=3.0.0",
    ],
    extras_require={
        "dev": [
            "pytest>=6.0",
            "pytest-cov",
            "black",
            "flake8",
            "mypy",
        ],
    },
    entry_points={
        "console_scripts": [
            "projpack=projpack.cli:cli_entry_point",
        ],
    },
    include_package_data=True,
    package_data={
        "projpack": ["*.md", "*.txt"],
    },
    project_urls={
        "Bug Reports": "https://github.com/yourusername/projpack/issues",
        "Source": "https://github.com/yourusername/projpack",
        "Documentation": "https://github.com/yourusername/projpack#readme",
    },
    keywords="project bundling ai tools development utility text processing",
)